package examples.animations;

import javafx.animation.FadeTransition;
import javafx.animation.ParallelTransition;
import javafx.animation.RotateTransition;
import javafx.animation.ScaleTransition;
import javafx.animation.SequentialTransition;
import javafx.animation.Timeline;
import javafx.animation.TranslateTransition;
import javafx.application.Application;
import javafx.geometry.Pos;
import javafx.scene.Group;
import javafx.scene.Scene;
import javafx.scene.canvas.Canvas;
import javafx.scene.canvas.GraphicsContext;
import javafx.scene.layout.FlowPane;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;
import javafx.stage.Stage;
import javafx.util.Duration;

public class SequentialTransitionExample extends Application {
	
    public static void main(String[] args) {
        launch(args);
    }
    
    @Override
    public void start(Stage primaryStage) {
        primaryStage.setTitle("Parallel Animations");

        FlowPane root = new FlowPane();
        root.setAlignment(Pos.CENTER);
        
        Rectangle rectParallel = new Rectangle(10,200,50, 50);
        rectParallel.setArcHeight(15);
        rectParallel.setArcWidth(15);
        rectParallel.setFill(Color.ORANGE);
        rectParallel.setTranslateX(50);
        rectParallel.setTranslateY(75);

        FadeTransition fadeTransition = 
                new FadeTransition(Duration.millis(3000), rectParallel);
            fadeTransition.setFromValue(1.0f);
            fadeTransition.setToValue(0.3f);
            fadeTransition.setCycleCount(2);
            fadeTransition.setAutoReverse(true);
            
            
        TranslateTransition translateTransition =
                new TranslateTransition(Duration.millis(2000), rectParallel);
            translateTransition.setFromX(50);
            translateTransition.setToX(350);
            translateTransition.setCycleCount(2);
            translateTransition.setAutoReverse(true);
            
        RotateTransition rotateTransition = 
                new RotateTransition(Duration.millis(3000), rectParallel);
            rotateTransition.setByAngle(180f);
            rotateTransition.setCycleCount(4);
            rotateTransition.setAutoReverse(true);
        
            ScaleTransition scaleTransition = 
                new ScaleTransition(Duration.millis(2000), rectParallel);
            scaleTransition.setToX(2f);
            scaleTransition.setToY(2f);
            scaleTransition.setCycleCount(2);
            scaleTransition.setAutoReverse(true);
            
            SequentialTransition sequentialTransition = new SequentialTransition(
                    fadeTransition,
                    translateTransition,
                    rotateTransition,
                    scaleTransition
            );
            
            sequentialTransition.setCycleCount(Timeline.INDEFINITE);
            sequentialTransition.play();
            
        
        root.getChildren().add(rectParallel);
        
        primaryStage.setWidth(900);
        primaryStage.setHeight(500);
        primaryStage.setScene(new Scene(root));
        primaryStage.show();
    }

}
