package examples.animations;
 
import javafx.animation.KeyFrame;
import javafx.animation.KeyValue;
import javafx.animation.Timeline;
import javafx.application.Application;
import javafx.beans.property.IntegerProperty;
import javafx.beans.property.SimpleIntegerProperty;
import javafx.event.ActionEvent;
import javafx.event.Event;
import javafx.event.EventHandler;
import javafx.geometry.Pos;
import javafx.scene.Group;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.layout.FlowPane;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.stage.Stage;
import javafx.util.Duration;



public class TimerTimelineWithAction extends Application {
 
    // private class constant and some variables
    private static final Integer STARTTIME = 15;
    private Timeline timeline = new Timeline();
    private Label timerLabel = new Label();
    // Make timeSeconds a Property
    private IntegerProperty timeSeconds = new SimpleIntegerProperty(STARTTIME);
           
 
    public static void main(String[] args) {
        Application.launch(args);
    }
 
    @Override
    public void start(Stage primaryStage) {
 
        // Setup the Stage and the Scene (the scene graph)
        primaryStage.setTitle("Timer");
        Group root = new Group();
        Scene scene = new Scene(root, 80, 30);
        
        // Bind the timerLabel text property to the timeSeconds property
        timerLabel.textProperty().bind(timeSeconds.asString());
        timerLabel.setTextFill(Color.BLACK);
        

        
        // a Button that controls the timer
        Button button = new Button();
        button.setText("start");
        button.setOnAction(e-> { 
                if (timeline != null) {
                    timeline.stop();
                }
                timerLabel.setTextFill(Color.BLACK);
                
                timeSeconds.set(STARTTIME);
                timeline = new Timeline(); // reset the timeline (ie the timer)
                timeline.getKeyFrames().add(
                        new KeyFrame(Duration.seconds(STARTTIME+1),
                        new KeyValue(timeSeconds, 0)));
                
                // an action happening when the animation finishes, again an event
                timeline.setOnFinished(e2->{
                		timerLabel.setTextFill(Color.RED);
                	}
                );
                
                timeline.playFromStart();
        });
 

        
        // layout
        FlowPane panel = new FlowPane(); 
        panel.getChildren().addAll(button, timerLabel);
        root.getChildren().add(panel);
 
        primaryStage.setScene(scene);
        primaryStage.show();
    }
}